@@ -280,6 +280,7 @@ prFpPrintLabels <- function(labels, nc, nr, graph.pos) {
   cols <- 1:(nc + 1)
   cols <- cols[cols != graph.pos]
   cols <- cols * 2 - 1
+
   for (label_col in 1:nc) {
     j <- cols[label_col]
     # The row
@@ -861,196 +862,6 @@ prGetTextGrobCex <- function(x) {
   return(cex)
 }
 
-
-#' Prepares the hrzl_lines for the plot
-#'
-#' @param total_columns Total number of columns
-#' @inheritParams forestplot
-#' @keywords internal
-#' @importFrom utils tail
-prFpGetLines <- function(hrzl_lines = NULL,
-                         is.summary,
-                         total_columns,
-                         col,
-                         shapes_gp = fpShapesGp()) {
-  ret_lines <- lapply(1:(length(is.summary) + 1), function(x) NULL)
-  if (is.null(hrzl_lines) ||
-      (is.logical(hrzl_lines) &&
-       all(hrzl_lines == FALSE)) ||
-      (is.list(hrzl_lines) &&
-       all(sapply(hrzl_lines, is.null)))) {
-    return(ret_lines)
-  }
-
-  std_line <- gpar(lty = 1, lwd = 1, col = col$hrz_lines, columns = 1:total_columns)
-  std_line <- prGetShapeGp(shapes_gp, NULL, "hrz_lines", default = std_line)
-
-  if (inherits(hrzl_lines, "gpar")) {
-    std_line <- prGparMerge(std_line, hrzl_lines)
-    hrzl_lines <- TRUE
-  }
-
-  # If provided with TRUE alone
-  # Note that FALSE has already been processed above
-  if (is.logical(hrzl_lines) &&
-    length(hrzl_lines) == 1) {
-    if (is.summary[1] == TRUE) {
-      line_pos <- which(is.summary == FALSE)[1]
-      ret_lines[[line_pos]] <-
-        std_line
-
-      is.summary[1:line_pos] <- FALSE
-    }
-
-    if (tail(is.summary, 1)) {
-      line_pos <- length(is.summary) + 1 - (which(rev(is.summary) == FALSE)[1] - 1)
-
-      ret_lines[[line_pos]] <-
-        std_line
-
-      ret_lines[[length(ret_lines)]] <-
-        std_line
-
-      is.summary[line_pos:length(is.summary)] <- FALSE
-    }
-
-    for (line_pos in which(is.summary == TRUE)) {
-      if (is.summary[line_pos + 1]) {
-        line_pos <-
-          line_pos +
-          tail(which(is.summary[(line_pos + 1):length(is.summary)]), 1)
-      }
-      ret_lines[[line_pos + 1]] <-
-        std_line
-    }
-
-    return(ret_lines)
-  }
-
-  if (is.logical(hrzl_lines)) {
-    if (length(hrzl_lines) == (length(is.summary) + 1)) {
-      ret_lines[[hrzl_lines]] <-
-        std_line
-      return(ret_lines)
-    } else {
-      stop(
-        "You have provided a logical hrzl_lines input of length '", length(hrzl_lines), "'",
-        " but the software expects the length to be number of rows + 1",
-        " i.e. ", length(is.summary), " + 1 = ", length(is.summary) + 1
-      )
-    }
-  }
-
-  if (!is.list(hrzl_lines)) {
-    stop("You have provided an invalid argument, expected a list but got a ", class(hrzl_lines))
-  }
-
-  if (is.null(names(hrzl_lines))) {
-    if (length(hrzl_lines) == (length(is.summary) + 1)) {
-      return(lapply(hrzl_lines, function(x, std) {
-        if (is.null(x)) {
-          x
-        } else if (inherits(x, "gpar")) {
-          prGparMerge(std, x)
-        } else {
-          std
-        }
-      },
-      std = std_line
-      ))
-    } else {
-      stop(
-        "You have provided a logical hrzl_lines input of length '", length(hrzl_lines), "'",
-        " but the software expects the length to be number of rows + 1",
-        " i.e. ", length(is.summary), " + 1 = ", length(is.summary) + 1
-      )
-    }
-  }
-
-  if (!all(sapply(hrzl_lines, function(x) inherits(x, "gpar") || x == TRUE))) {
-    stop("The list must consist of only gpar or logical TRUE elements")
-  }
-
-  for (n in names(hrzl_lines)) {
-    nn <- as.integer(n)
-    if (is.na(nn)) {
-      stop("Your name '", n, "' for the list gpars cannot be converted to an integer")
-    }
-    if (!nn %in% 1:(length(is.summary) + 1)) {
-      stop(
-        "The integer that you have provided '", n, "'",
-        " falls outside the scope of possible values 1:", length(is.summary) + 1
-      )
-    }
-    if (is.logical(hrzl_lines[[n]])) {
-      ret_lines[[nn]] <-
-        std_line
-    } else {
-      ret_lines[[nn]] <-
-        prGparMerge(std_line, hrzl_lines[[n]])
-    }
-  }
-
-  return(ret_lines)
-}
-
-#' Draws the horizontal lines
-#'
-#' @param nr Number of rows
-#' @param colwidths Vector with column widths
-#' @inheritParams prFpGetLines
-#' @inheritParams forestplot
-#' @keywords internal
-prFpDrawLines <- function(hrzl_lines, nr, colwidths,
-                          graph.pos) {
-  getCSpan <- function(columns, colwidths) {
-    span_cols <- c()
-    col_pos <- NULL
-    for (i in 1:length(columns)) {
-      pos <- columns[i]
-      pos <- pos * 2 - 1
-      span_cols <- c(span_cols, pos)
-
-      if (pos < length(colwidths) &&
-        i != length(columns) &&
-        columns[i] + 1 == columns[i + 1]) {
-        span_cols <- c(span_cols, pos + 1)
-      }
-    }
-
-    span_cols
-  }
-
-  for (i in 1:nr) {
-    if (!is.null(hrzl_lines[[i]])) {
-      span_cols <- getCSpan(hrzl_lines[[i]]$columns, colwidths)
-
-      for (c in span_cols) {
-        line_vp <- viewport(
-          layout.pos.row = i,
-          layout.pos.col = c
-        )
-        pushViewport(line_vp)
-        grid.lines(y = unit(c(1, 1), "npc"), gp = hrzl_lines[[i]])
-        popViewport()
-      }
-    }
-
-    if (i == nr &&
-      !is.null(hrzl_lines[[i + 1]])) {
-      span_cols <- getCSpan(hrzl_lines[[i + 1]]$columns, colwidths)
-
-      line_vp <- viewport(
-        layout.pos.row = i,
-        layout.pos.col = span_cols
-      )
-      pushViewport(line_vp)
-      grid.lines(y = unit(c(0, 0), "npc"), gp = hrzl_lines[[i + 1]])
-      popViewport()
-    }
-  }
-}
-
 #' Merges two \code{\link[grid]{gpar}} elements
 #'
 #' The second elements overrides any conflicting elements within the first
